@@ -6,7 +6,6 @@ use strict;
 use English qw(-no_match_vars);
 use base qw(Exporter);
 use Carp qw(croak);
-use ALPM;
 
 my %_PKG_ATTRIBS = map { /^has_(.*)$/ ? ( $1 => $_ ) : ( $_ => $_ ) }
     qw { filename name version desc url
@@ -65,7 +64,7 @@ sub attribs_ref
 
 =head1 NAME
 
-ALPM::Package - Class representing an alpm package
+ALPM::Package - ALPM package class.
 
 =head1 SYNOPSIS
 
@@ -212,11 +211,11 @@ L<ALPM>, L<ALPM::DB>
 
 =head1 AUTHOR
 
-Justin Davis, C<< <jrcd83 at gmail> >>
+Justin Davis, C<< <juster at cpan dot org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 by Justin Davis
+Copyright (C) 2010 by Justin Davis
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
